﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace IndustryConnect.Bootcamp.UnitTest
{
    public interface IJobService
    {
        bool ApplyJob(string candidateName, int experienceLevel, string cv);
    }

    public interface ICvService
    {
        bool CheckCv(string cv);
    }



    public class JobService : IJobService
    {
        private readonly ICvService _cvService;

        public JobService(ICvService cvService)
        {
            _cvService = cvService;
        }

        public bool ApplyJob(string candidateName, int experienceLevel, string cv)
        {
            if (string.IsNullOrWhiteSpace(candidateName))
            {
                throw new ArgumentException("Invaid candidateName", "candidateName", new Exception("It must be an valid person's name"));
            }

            if (string.IsNullOrWhiteSpace(cv))
            {
                throw new ArgumentException("Invaid CV");
            }

            if (experienceLevel <= 0)
            {
                return false;
            }

            try
            {
                return _cvService.CheckCv(cv);
            }
            catch
            {
                // In case cv service throws error, we treat it as a bad CV.
                // This will be covered in the unit testing.
                return false; 
            }
            
        }

    }

    public class CvService : ICvService
    {
        public bool CheckCv(string cv)
        {
            if (!cv.Contains("Experience")) return false;

            return true;
        }
    }
}
